@@ -32,81 +32,85 @@
 #ifndef _COMMON_H
 #define _COMMON_H
 
+#define AUDIO_DEVICE_NAME   "audio-device-name"
 #define ALSA_MIXER			"alsa-mixer"
-#define CACHE_SIZE		"cache_size"
-#define PLUGIN_AUDIO_CACHE_SIZE		"plugin_audio_cache_size"
-#define PLUGIN_VIDEO_CACHE_SIZE		"plugin_video_cache_size"
-#define OSDLEVEL		"osdlevel"
-#define PPLEVEL			"pplevel"
-#define SOFTVOL			"softvol"
-#define VOLUME_GAIN		"volume_gain"
-#define REMEMBER_SOFTVOL	"remember_softvol"
-#define VOLUME_SOFTVOL	"volume_softvol"
-#define VERBOSE			"verbose"
-#define VERTICAL		"vertical"
-#define FORCECACHE		"forcecache"
-#define LAST_DIR		"last_dir"
-#define SHOWPLAYLIST	"showplaylist"
-#define SHOWDETAILS		"showdetails"
-#define SHOW_CONTROLS   "show_controls"
-#define DISABLEASS          "disableass"
-#define DISABLEEMBEDDEDFONTS    "disableembeddedfonts"
-#define DISABLEDEINTERLACE	"disable_deinterlace"
-#define DISABLEFRAMEDROP	"disableframedrop"
-#define DISABLEFULLSCREEN	"disablefullscreen"
-#define DISABLECONTEXTMENU	"disablecontextmenu"
-#define DISABLEPAUSEONCLICK	"disable_pause_on_click"
-#define DISABLEANIMATION	"disable_animation"
-#define AUTOHIDETIMEOUT	"auto_hide_timeout"
-#define METADATACODEPAGE	"metadatacodepage"
-#define SUBTITLEFONT	"subtitlefont"
-#define SUBTITLESCALE	"subtitlescale"
-#define SUBTITLECODEPAGE	"subtitlecodepage"
-#define SUBTITLECOLOR	"subtitlecolor"
-#define SUBTITLEOUTLINE "subtitleoutline"
-#define SUBTITLESHADOW "subtitleshadow"
-#define SUBTITLE_MARGIN "subtitle_margin"
-#define TRACKER_POSITION "tracker_position"
-#define MOUSE_WHEEL_CHANGES_VOLUME "mouse_wheel_changes_volume"
+#define VOLUME				"volume"
+#define AUDIO_CHANNELS		"audio-channels"
+#define USE_HW_AUDIO		"use-hw-audio"
+#define SOFTVOL				"softvol"
+#define VOLUME_GAIN			"volume-gain"
+#define REMEMBER_SOFTVOL	"remember-softvol"
+#define VOLUME_SOFTVOL		"volume-softvol"
 
-#define VOLUME	"volume"
-#define AUDIO_CHANNELS "audio_channels"
-#define USE_HW_AUDIO "use_hw_audio"
-#define USE_MEDIAKEYS		"use_mediakeys"
-#define USE_DEFAULTPL		"use_defaultpl"
-#define DISABLE_COVER_ART_FETCH "disable_cover_art_fetch"
-#define FULLSCREEN	"fullscreen"
+#define CACHE_SIZE				"cache-size"
+#define PLUGIN_AUDIO_CACHE_SIZE	"plugin-audio-cache-size"
+#define PLUGIN_VIDEO_CACHE_SIZE	"plugin-video-cache-size"
+#define OSDLEVEL				"osd-level"
+#define PPLEVEL					"pp-level"
+#define VERBOSE					"verbose"
+#define VERTICAL				"vertical"
+#define FORCECACHE				"force-cache"
+#define LAST_DIR				"last-dir"
+#define SHOWPLAYLIST			"show-playlist"
+#define SHOWDETAILS				"show-details"
+#define SHOW_CONTROLS			"show-controls"
 
+#define DISABLEASS      		"disable-ass"
+#define DISABLEEMBEDDEDFONTS    "disable-embeddedfonts"
+#define DISABLEDEINTERLACE		"disable-deinterlace"
+#define DISABLEFRAMEDROP		"disable-framedrop"
+#define DISABLEFULLSCREEN		"disable-fullscreen"
+#define DISABLECONTEXTMENU		"disable-contextmenu"
+#define DISABLEPAUSEONCLICK		"disable-pause-on-click"
+#define DISABLEANIMATION		"disable-animation"
+#define DISABLE_COVER_ART_FETCH "disable-cover-art-fetch"
 
-#define MPLAYER_BIN		"mplayer_bin"
-#define EXTRAOPTS		"extraopts"
-#define USE_XSCRNSAVER "use_xscrnsaver"
-#define MPLAYER_DVD_DEVICE "mplayer_dvd_device"
+#define AUTOHIDETIMEOUT		"auto-hide-timeout"
+#define METADATACODEPAGE	"metadata-codepage"
 
-#define DISABLE_QT		"disable_qt"
-#define DISABLE_REAL	"disable_real"
-#define DISABLE_WMP		"disable_wmp"
-#define DISABLE_DVX		"disable_dvx"
-#define DISABLE_MIDI    "disable_midi"
-#define DISABLE_EMBEDDING		"disable_embedding"
+#define SHOW_SUBTITLES		"show-subtitles"
+#define SUBTITLEFONT		"subtitle-font"
+#define SUBTITLESCALE		"subtitle-scale"
+#define SUBTITLECODEPAGE	"subtitle-codepage"
+#define SUBTITLECOLOR		"subtitle-color"
+#define SUBTITLEOUTLINE		"subtitle-outline"
+#define SUBTITLESHADOW		"subtitle-shadow"
+#define SUBTITLE_MARGIN		"subtitle-margin"
+#define SUBTITLE_FUZZINESS  "subtitle-fuzziness"
 
-#define REMEMBER_LOC		"remember_loc"
-#define WINDOW_X		"window_x"
-#define WINDOW_Y		"window_y"
-#define WINDOW_HEIGHT	"window_height"
-#define WINDOW_WIDTH	"window_width"
-#define PANEL_POSITION	    "panel_position"
+#define MOUSE_WHEEL_CHANGES_VOLUME "mouse-wheel-changes-volume"
+#define USE_MEDIAKEYS		"use-mediakeys"
+#define USE_DEFAULTPL		"use-defaultpl"
+#define FULLSCREEN			"fullscreen"
+#define MPLAYER_BIN			"mplayer-bin"
+#define EXTRAOPTS			"extraopts"
+#define MPLAYER_DVD_DEVICE  "mplayer-dvd-device"
 
-#define RESIZE_ON_NEW_MEDIA "resize_on_new_media"
-#define KEEP_ON_TOP		"keep_on_top"
-#define SINGLE_INSTANCE "single_instance"
-#define REPLACE_AND_PLAY "replace_and_play"
-#define BRING_TO_FRONT  "bring_to_front"
-#define SHOW_NOTIFICATION "show_notification"
-#define SHOW_STATUS_ICON "show_status_icon"
-#define SHOW_SUBTITLES "show_subtitles"
+#define REMEMBER_LOC		"remember-loc"
+#define WINDOW_X			"window-x"
+#define WINDOW_Y			"window-y"
+#define WINDOW_HEIGHT		"window-height"
+#define WINDOW_WIDTH		"window-width"
+#define PANEL_POSITION	    "panel-position"
+#define RESIZE_ON_NEW_MEDIA "resize-on-new-media"
+#define KEEP_ON_TOP			"keep-on-top"
+#define SINGLE_INSTANCE		"single-instance"
+#define REPLACE_AND_PLAY	"replace-and-play"
+#define BRING_TO_FRONT		"bring-to-front"
+#define SHOW_NOTIFICATION   "show-notification"
+#define SHOW_STATUS_ICON	"show-status-icon"
+#define USE_XSCRNSAVER		"use-xscrnsaver"
 
-#define AUDIO_DEVICE_NAME "audio-device-name"
+#define DISABLE_QT			"disable-qt"
+#define DISABLE_REAL		"disable-real"
+#define DISABLE_WMP			"disable-wmp"
+#define DISABLE_DVX			"disable-dvx"
+#define DISABLE_MIDI		"disable-midi"
+#define DISABLE_EMBEDDING	"disable-embedding"
+#define DISABLE_EMBEDDED_SCALING "disable-embedded-scaling"
+
+// set this to true in gconf/dconf when using with gnome global menus
+#define ENABLE_GLOBAL_MENU  "enable-global-menu"
 
 // JavaScript Playstates
 #define STATE_UNDEFINED     0
@@ -130,75 +134,36 @@ typedef enum {
     QUIT
 } PLAYSTATE;
 
-typedef enum {
-    NO_ERROR,
-    ERROR_RETRY_WITH_PLAYLIST,
-    ERROR_RETRY_WITH_HTTP,
-    ERROR_RETRY_WITH_MMSHTTP
-} PLAYBACK_ERROR;
-
-PLAYSTATE state;
 PLAYSTATE guistate;
 PLAYSTATE lastguistate;
-PLAYBACK_ERROR playback_error;
 
 typedef struct _IdleData {
     gchar info[1024];
     gchar display_name[1024];
     gchar media_info[2048];
     gchar media_notification[2048];
-    gchar url[1024];
     gchar af_export[1024];
+    gchar url[2048];
     GMappedFile *mapped_af_export;
-    gint windowid;
     gchar *device;
-    gdouble percent;
     gdouble cachepercent;
     gint streaming;
-    gboolean seekable;
     gchar progress_text[1024];
-    gdouble volume;
-    gboolean mute;
     gchar vol_tooltip[128];
-    gint x;
-    gint y;
-    gint last_x;
-    gint last_y;
-    gint original_h;
-    gint original_w;
     gint width;
     gint height;
     gboolean videopresent;
-    gboolean audiopresent;
     gboolean fullscreen;
     gboolean showcontrols;
     gdouble position;
     gdouble length;
     gdouble start_time;
     glong byte_pos;
-    gint chapters;
-    gint brightness;
-    gint contrast;
-    gint gamma;
-    gint hue;
-    gint saturation;
     gchar demuxer[64];
-    gchar video_format[64];
-    gchar video_codec[16];
-    gchar video_fps[16];
-    gchar video_bitrate[16];
-    gchar audio_codec[16];
-    gchar audio_bitrate[16];
-    gchar audio_samplerate[16];
-    gchar audio_channels[16];
     gchar metadata[1024];
     gboolean fromdbus;
     gboolean window_resized;
-    gboolean has_chapters;
     gboolean tmpfile;
-    gboolean sub_visible;
-    gint sub_demux;
-    gint switch_audio;
     gboolean retry_on_full_cache;
 #ifdef GIO_ENABLED
     GFile *src;
@@ -209,22 +174,13 @@ typedef struct _IdleData {
 #endif
 } IdleData;
 
-IdleData *idledata;
-
-
-typedef struct _ThreadData {
-    gchar uri[2048];
-    gchar filename[1024];
-    gchar subtitle[1024];
-    gchar audiofile[1024];
-    gint streaming;
-    gint player_window;
+typedef struct _PlayData {
+    gchar uri[4096];
     gint playlist;
-    gint restart_second;
-    gint start_second;
-    gint play_length;
-    gboolean done;
-} ThreadData;
+} PlayData;
+
+
+IdleData *idledata;
 
 enum {
     ITEM_COLUMN,
@@ -296,7 +252,6 @@ gint max_buckets[METER_BARS];
 #define DRAG_NAME_2		"STRING"
 #define DRAG_INFO_2		2
 
-gchar *lastfile;
 gint cache_size;
 gint plugin_audio_cache_size;
 gint plugin_video_cache_size;
@@ -316,7 +271,7 @@ gint window_y;
 gint control_id;
 gboolean softvol;
 gboolean remember_softvol;
-gint volume_softvol;
+gdouble volume_softvol;
 gint volume_gain;
 gint verbose;
 gint reallyverbose;
@@ -338,6 +293,7 @@ gboolean disable_framedrop;
 gboolean disable_context_menu;
 gboolean disable_fullscreen;
 gboolean disable_pause_on_click;
+gboolean enable_global_menu;
 gint loop;
 gint start_second;
 gint play_length;
@@ -356,8 +312,8 @@ gchar *subtitle;
 gchar *alang;
 gchar *slang;
 gchar *metadata_codepage;
-gint volume;
 gboolean use_volume_option;
+gboolean use_mplayer2;
 gboolean vertical_layout;
 gboolean playlist_visible;
 gboolean details_visible;
@@ -375,12 +331,12 @@ gboolean always_hide_after_timeout;
 gboolean mouse_over_controls;
 gchar *subtitlefont;
 gdouble subtitle_scale;
-gdouble subtitle_delay;
 gchar *subtitle_codepage;
 gchar *subtitle_color;
 gboolean subtitle_outline;
 gboolean subtitle_shadow;
 gint subtitle_margin;
+gint subtitle_fuzziness;
 gboolean quit_on_complete;
 gchar *mplayer_bin;
 gchar *mplayer_dvd_device;
@@ -423,7 +379,6 @@ gint tv_width;
 gint tv_height;
 gint tv_fps;
 
-GThread *thread;
 GMutex *slide_away;
 GCond *mplayer_complete_cond;
 
@@ -431,7 +386,6 @@ GThreadPool *retrieve_metadata_pool;
 
 gboolean use_mediakeys;
 gboolean use_defaultpl;
-gboolean dvdnav_title_is_menu;
 
 gboolean qt_disabled;
 gboolean real_disabled;
@@ -439,6 +393,7 @@ gboolean wmp_disabled;
 gboolean dvx_disabled;
 gboolean midi_disabled;
 gboolean embedding_disabled;
+gboolean disable_embedded_scaling;
 
 GArray *data;
 GArray *max_data;
@@ -453,6 +408,7 @@ gint non_fs_height;
 // playlist stuff
 GtkListStore *playliststore;
 GtkTreeIter iter;
+GtkTreeIter *next_iter;
 GtkTreeSelection *selection;
 GtkWidget *list;
 
@@ -468,6 +424,7 @@ void adjust_layout();
 gboolean hide_buttons(void *data);
 gboolean show_copyurl(void *data);
 
+gboolean set_gui_state(void *data);
 gboolean set_media_info(void *data);
 gboolean set_media_label(void *data);
 gboolean set_cover_art(gpointer pixbuf);
@@ -476,7 +433,6 @@ gboolean set_progress_text(void *data);
 gboolean set_progress_time(void *data);
 gboolean set_volume_from_slider(gpointer data);
 gboolean set_volume_tip(void *data);
-gboolean set_gui_state(void *data);
 gboolean resize_window(void *data);
 gboolean set_play(void *data);
 gboolean set_pause(void *data);
@@ -522,8 +478,7 @@ void menuitem_edit_random_callback(GtkMenuItem * menuitem, void *data);
 
 gboolean update_audio_meter(gpointer data);
 
-void mplayer_shutdown();
-gpointer launch_player(gpointer data);
+void set_media_player_attributes(GtkWidget * widget);
 
 gboolean update_mplayer_config();
 gboolean read_mplayer_config();
@@ -533,12 +488,12 @@ void retrieve_metadata(gpointer data, gpointer user_data);
 gchar *default_playlist;
 gboolean safe_to_save_default_playlist;
 
+gint pref_volume;
+gboolean async_play_iter(void *data);
+
 #ifdef GTK2_12_ENABLED
 GtkRecentManager *recent_manager;
 void recent_manager_changed_callback(GtkRecentManager * recent_manager, gpointer data);
 #endif
 
-GValue ALLOW_SHRINK_TRUE;
-GValue ALLOW_SHRINK_FALSE;
-
 #endif                          /* _COMMON_H */
