@@ -51,8 +51,8 @@ indent -kr -l100 -i4 -nut
 static DBusHandlerResult filter_func(DBusConnection * connection, DBusMessage * message, void *user_data)
 {
 
-    const gchar *sender;
-    const gchar *destination;
+    //const gchar *sender;
+    //const gchar *destination;
     gint message_type;
     gchar *s = NULL;
     gchar *hrefid = NULL;
@@ -69,10 +69,13 @@ static DBusHandlerResult filter_func(DBusConnection * connection, DBusMessage *
     gint source_id;
     gint bitrate;
     ButtonDef *b;
+    gdouble volume;
+    gdouble percent;
+    gdouble duration;
 
     message_type = dbus_message_get_type(message);
-    sender = dbus_message_get_sender(message);
-    destination = dbus_message_get_destination(message);
+    //sender = dbus_message_get_sender(message);
+    //destination = dbus_message_get_destination(message);
 
     /*
        printf("path=%s; interface=%s; member=%s; data=%s\n",
@@ -98,7 +101,9 @@ static DBusHandlerResult filter_func(DBusConnection * connection, DBusMessage *
             // printf("Path matched %s\n", dbus_message_get_path(message));
             if (message_type == DBUS_MESSAGE_TYPE_SIGNAL) {
                 if (g_ascii_strcasecmp(dbus_message_get_member(message), "Open") == 0) {
-                    g_idle_add(set_kill_mplayer, NULL);
+                    if (gmtk_media_player_get_state(GMTK_MEDIA_PLAYER(media)) != MEDIA_STATE_UNKNOWN)
+                        dontplaynext = TRUE;
+                    gmtk_media_player_set_state(GMTK_MEDIA_PLAYER(media), MEDIA_STATE_QUIT);
                     dbus_error_init(&error);
                     if (dbus_message_get_args(message, &error, DBUS_TYPE_STRING, &s, DBUS_TYPE_INVALID)) {
                         if (strlen(s) > 0) {
@@ -306,15 +311,16 @@ static DBusHandlerResult filter_func(DBusConnection * connection, DBusMessage *
 					dbus_unhook();
                     gtk_main_quit();
 */
-                    dontplaynext = TRUE;
+                    if (gmtk_media_player_get_state(GMTK_MEDIA_PLAYER(media)) != MEDIA_STATE_UNKNOWN)
+                        dontplaynext = TRUE;
                     g_idle_add(set_quit, idledata);
                     return DBUS_HANDLER_RESULT_HANDLED;
                 }
 
                 if (g_ascii_strcasecmp(dbus_message_get_member(message), "Volume") == 0 && idledata != NULL) {
                     dbus_error_init(&error);
-                    if (dbus_message_get_args
-                        (message, &error, DBUS_TYPE_DOUBLE, &(idledata->volume), DBUS_TYPE_INVALID)) {
+                    if (dbus_message_get_args(message, &error, DBUS_TYPE_DOUBLE, &volume, DBUS_TYPE_INVALID)) {
+                        audio_device.volume = volume / 100.0;
                         g_idle_add(set_volume, idledata);
                     } else {
                         dbus_error_free(&error);
@@ -323,16 +329,20 @@ static DBusHandlerResult filter_func(DBusConnection * connection, DBusMessage *
                 }
 
                 if (g_ascii_strcasecmp(dbus_message_get_member(message), "VolumeUp") == 0 && idledata != NULL) {
-                    if (idledata->volume < 100) {
-                        idledata->volume++;
+                    if (audio_device.volume < 1.0) {
+                        audio_device.volume += 0.10;
+                        if (audio_device.volume > 1.0)
+                            audio_device.volume = 1.0;
                         g_idle_add(set_volume, idledata);
                     }
                     return DBUS_HANDLER_RESULT_HANDLED;
                 }
 
                 if (g_ascii_strcasecmp(dbus_message_get_member(message), "VolumeDown") == 0 && idledata != NULL) {
-                    if (idledata->volume > 0) {
-                        idledata->volume--;
+                    if (audio_device.volume > 0.0) {
+                        audio_device.volume -= 0.10;
+                        if (audio_device.volume < 0.0)
+                            audio_device.volume = 0.0;
                         g_idle_add(set_volume, idledata);
                     }
                     return DBUS_HANDLER_RESULT_HANDLED;
@@ -341,10 +351,11 @@ static DBusHandlerResult filter_func(DBusConnection * connection, DBusMessage *
                 if (g_ascii_strcasecmp(dbus_message_get_member(message), "RP_Volume") == 0 && idledata != NULL) {
                     dbus_error_init(&error);
                     if (dbus_message_get_args
-                        (message, &error, DBUS_TYPE_DOUBLE, &(idledata->volume), DBUS_TYPE_INT32,
+                        (message, &error, DBUS_TYPE_DOUBLE, &(volume), DBUS_TYPE_INT32,
                          &source_id, DBUS_TYPE_INVALID)) {
                         if (source_id != control_id) {
                             idledata->fromdbus = TRUE;
+                            audio_device.volume = volume / 100.0;
                             g_idle_add(set_volume, idledata);
                         }
                     } else {
@@ -366,8 +377,11 @@ static DBusHandlerResult filter_func(DBusConnection * connection, DBusMessage *
 
                 if (g_ascii_strcasecmp(dbus_message_get_member(message), "SetPercent") == 0 && idledata != NULL) {
                     dbus_error_init(&error);
-                    if (dbus_message_get_args
-                        (message, &error, DBUS_TYPE_DOUBLE, &(idledata->percent), DBUS_TYPE_INVALID)) {
+                    if (dbus_message_get_args(message, &error, DBUS_TYPE_DOUBLE, &percent, DBUS_TYPE_INVALID)) {
+                        gmtk_media_player_seek(GMTK_MEDIA_PLAYER(media),
+                                               gmtk_media_player_get_attribute_double(GMTK_MEDIA_PLAYER(media),
+                                                                                      ATTRIBUTE_LENGTH) * percent,
+                                               SEEK_ABSOLUTE);
                         g_idle_add(set_progress_value, idledata);
                     } else {
                         dbus_error_free(&error);
@@ -378,11 +392,13 @@ static DBusHandlerResult filter_func(DBusConnection * connection, DBusMessage *
                 if (g_ascii_strcasecmp(dbus_message_get_member(message), "RP_SetPercent") == 0 && idledata != NULL) {
                     dbus_error_init(&error);
                     if (dbus_message_get_args
-                        (message, &error, DBUS_TYPE_DOUBLE, &(idledata->percent), DBUS_TYPE_INT32,
-                         &source_id, DBUS_TYPE_INVALID)) {
+                        (message, &error, DBUS_TYPE_DOUBLE, &percent, DBUS_TYPE_INT32, &source_id, DBUS_TYPE_INVALID)) {
                         if (source_id != control_id) {
                             idledata->fromdbus = TRUE;
-                            g_idle_add(set_progress_value, idledata);
+                            gmtk_media_player_seek(GMTK_MEDIA_PLAYER(media),
+                                                   gmtk_media_player_get_attribute_double(GMTK_MEDIA_PLAYER(media),
+                                                                                          ATTRIBUTE_LENGTH) * percent,
+                                                   SEEK_ABSOLUTE);
                         }
                     } else {
                         dbus_error_free(&error);
@@ -411,7 +427,7 @@ static DBusHandlerResult filter_func(DBusConnection * connection, DBusMessage *
                     dbus_error_init(&error);
                     if (dbus_message_get_args(message, &error, DBUS_TYPE_STRING, &s, DBUS_TYPE_INVALID)) {
                         g_strlcpy(idledata->progress_text, s, 1024);
-                        if (state != PLAYING)
+                        if (gmtk_media_player_get_state(GMTK_MEDIA_PLAYER(media)) != MEDIA_STATE_PLAY)
                             g_idle_add(set_progress_text, idledata);
                     } else {
                         dbus_error_free(&error);
@@ -475,7 +491,8 @@ static DBusHandlerResult filter_func(DBusConnection * connection, DBusMessage *
                 if (g_ascii_strcasecmp(dbus_message_get_member(message), "SetURL") == 0) {
                     dbus_error_init(&error);
                     if (dbus_message_get_args(message, &error, DBUS_TYPE_STRING, &s, DBUS_TYPE_INVALID)) {
-                        g_strlcpy(idledata->url, s, 1024);
+                        gmtk_media_player_set_uri(GMTK_MEDIA_PLAYER(media), s);
+                        g_strlcpy(idledata->url, s, 2048);
                         g_idle_add(show_copyurl, idledata);
                     } else {
                         dbus_error_free(&error);
@@ -613,6 +630,8 @@ static DBusHandlerResult filter_func(DBusConnection * connection, DBusMessage *
                                           "    </method>\n"
                                           "    <method name=\"GetURI\">\n"
                                           "    </method>\n"
+                                          "    <method name=\"GetTitle\">\n"
+                                          "    </method>\n"
                                           "    <signal name=\"Open\">\n"
                                           "        <arg name=\"url\" type=\"s\" />\n"
                                           "    </signal>\n"
@@ -650,7 +669,8 @@ static DBusHandlerResult filter_func(DBusConnection * connection, DBusMessage *
                 }
                 if (dbus_message_is_method_call(message, "com.gnome.mplayer", "GetVolume")) {
                     reply_message = dbus_message_new_method_return(message);
-                    dbus_message_append_args(reply_message, DBUS_TYPE_DOUBLE, &idledata->volume, DBUS_TYPE_INVALID);
+                    volume = audio_device.volume * 100.0;
+                    dbus_message_append_args(reply_message, DBUS_TYPE_DOUBLE, &volume, DBUS_TYPE_INVALID);
                     dbus_connection_send(connection, reply_message, NULL);
                     dbus_message_unref(reply_message);
                     return DBUS_HANDLER_RESULT_HANDLED;
@@ -672,21 +692,25 @@ static DBusHandlerResult filter_func(DBusConnection * connection, DBusMessage *
                 }
                 if (dbus_message_is_method_call(message, "com.gnome.mplayer", "GetTime")) {
                     reply_message = dbus_message_new_method_return(message);
-                    dbus_message_append_args(reply_message, DBUS_TYPE_DOUBLE, &idledata->position, DBUS_TYPE_INVALID);
+                    duration = gmtk_media_player_get_attribute_double(GMTK_MEDIA_PLAYER(media), ATTRIBUTE_POSITION);
+                    dbus_message_append_args(reply_message, DBUS_TYPE_DOUBLE, &duration, DBUS_TYPE_INVALID);
                     dbus_connection_send(connection, reply_message, NULL);
                     dbus_message_unref(reply_message);
                     return DBUS_HANDLER_RESULT_HANDLED;
                 }
                 if (dbus_message_is_method_call(message, "com.gnome.mplayer", "GetDuration")) {
                     reply_message = dbus_message_new_method_return(message);
-                    dbus_message_append_args(reply_message, DBUS_TYPE_DOUBLE, &idledata->length, DBUS_TYPE_INVALID);
+                    duration = gmtk_media_player_get_attribute_double(GMTK_MEDIA_PLAYER(media), ATTRIBUTE_LENGTH);
+                    dbus_message_append_args(reply_message, DBUS_TYPE_DOUBLE, &duration, DBUS_TYPE_INVALID);
                     dbus_connection_send(connection, reply_message, NULL);
                     dbus_message_unref(reply_message);
                     return DBUS_HANDLER_RESULT_HANDLED;
                 }
                 if (dbus_message_is_method_call(message, "com.gnome.mplayer", "GetPercent")) {
                     reply_message = dbus_message_new_method_return(message);
-                    dbus_message_append_args(reply_message, DBUS_TYPE_DOUBLE, &idledata->percent, DBUS_TYPE_INVALID);
+                    percent =
+                        gmtk_media_player_get_attribute_double(GMTK_MEDIA_PLAYER(media), ATTRIBUTE_POSITION_PERCENT);
+                    dbus_message_append_args(reply_message, DBUS_TYPE_DOUBLE, &percent, DBUS_TYPE_INVALID);
                     dbus_connection_send(connection, reply_message, NULL);
                     dbus_message_unref(reply_message);
                     return DBUS_HANDLER_RESULT_HANDLED;
@@ -720,6 +744,29 @@ static DBusHandlerResult filter_func(DBusConnection * connection, DBusMessage *
                 }
                 if (dbus_message_is_method_call(message, "com.gnome.mplayer", "GetPlayState")) {
                     reply_message = dbus_message_new_method_return(message);
+                    if (gmtk_media_player_get_state(GMTK_MEDIA_PLAYER(media)) == MEDIA_STATE_PAUSE) {
+                        js_state = STATE_PAUSED;
+                    }
+
+                    if (gmtk_media_player_get_state(GMTK_MEDIA_PLAYER(media)) == MEDIA_STATE_STOP) {
+                        js_state = STATE_STOPPED;
+                    }
+
+                    if (gmtk_media_player_get_state(GMTK_MEDIA_PLAYER(media)) == MEDIA_STATE_PLAY) {
+                        js_state = STATE_PLAYING;
+                    }
+
+                    if (gmtk_media_player_get_state(GMTK_MEDIA_PLAYER(media)) == MEDIA_STATE_BUFFERING) {
+                        js_state = STATE_BUFFERING;
+                    }
+
+                    if (gmtk_media_player_get_attribute_double(GMTK_MEDIA_PLAYER(media), ATTRIBUTE_POSITION) == 0) {
+                        if (gmtk_media_player_get_attribute_double
+                            (GMTK_MEDIA_PLAYER(media), ATTRIBUTE_CACHE_PERCENT) > 0.0) {
+                            js_state = STATE_BUFFERING;
+                        }
+                    }
+
                     dbus_message_append_args(reply_message, DBUS_TYPE_INT32, &js_state, DBUS_TYPE_INVALID);
                     dbus_connection_send(connection, reply_message, NULL);
                     dbus_message_unref(reply_message);
@@ -731,7 +778,12 @@ static DBusHandlerResult filter_func(DBusConnection * connection, DBusMessage *
                         bitrate = get_bitrate(s);
                     } else {
                         dbus_error_free(&error);
-                        bitrate = 0;
+                        bitrate =
+                            gmtk_media_player_get_attribute_integer(GMTK_MEDIA_PLAYER(media), ATTRIBUTE_VIDEO_BITRATE);
+                        if (bitrate == 0)
+                            bitrate =
+                                gmtk_media_player_get_attribute_integer(GMTK_MEDIA_PLAYER(media),
+                                                                        ATTRIBUTE_AUDIO_BITRATE);
                     }
                     reply_message = dbus_message_new_method_return(message);
                     dbus_message_append_args(reply_message, DBUS_TYPE_INT32, &bitrate, DBUS_TYPE_INVALID);
@@ -747,6 +799,26 @@ static DBusHandlerResult filter_func(DBusConnection * connection, DBusMessage *
                     dbus_message_unref(reply_message);
                     return DBUS_HANDLER_RESULT_HANDLED;
                 }
+                if (dbus_message_is_method_call(message, "com.gnome.mplayer", "GetTitle")) {
+                    reply_message = dbus_message_new_method_return(message);
+                    if (gmtk_media_player_get_attribute_string(GMTK_MEDIA_PLAYER(media), ATTRIBUTE_TITLE) == NULL) {
+                        s = g_strdup(idledata->display_name);
+                    } else {
+                        s = g_strdup(gmtk_media_player_get_attribute_string(GMTK_MEDIA_PLAYER(media), ATTRIBUTE_TITLE));
+                    }
+                    dbus_message_append_args(reply_message, DBUS_TYPE_STRING, &s, DBUS_TYPE_INVALID);
+                    dbus_connection_send(connection, reply_message, NULL);
+                    dbus_message_unref(reply_message);
+                    return DBUS_HANDLER_RESULT_HANDLED;
+                }
+                if (dbus_message_is_method_call(message, "com.gnome.mplayer", "GetCachePercent")) {
+                    reply_message = dbus_message_new_method_return(message);
+                    percent = gmtk_media_player_get_attribute_double(GMTK_MEDIA_PLAYER(media), ATTRIBUTE_CACHE_PERCENT);
+                    dbus_message_append_args(reply_message, DBUS_TYPE_DOUBLE, &percent, DBUS_TYPE_INVALID);
+                    dbus_connection_send(connection, reply_message, NULL);
+                    dbus_message_unref(reply_message);
+                    return DBUS_HANDLER_RESULT_HANDLED;
+                }
                 printf("Unable to find method call\n");
             } else {
                 if (verbose)
@@ -1172,6 +1244,7 @@ void dbus_disable_screensaver()
     const gchar *app;
     const gchar *reason;
     gint flags;
+    gint windowid;
 #endif
 #endif
 
@@ -1217,8 +1290,9 @@ void dbus_disable_screensaver()
                 app = g_strdup_printf("gnome-mplayer");
                 reason = g_strdup_printf("playback");
                 flags = 8;
+                windowid = GDK_WINDOW_XID(get_window(window));
                 dbus_message_append_args(message, DBUS_TYPE_STRING, &app, DBUS_TYPE_UINT32,
-                                         &(idledata->windowid), DBUS_TYPE_STRING, &reason,
+                                         &windowid, DBUS_TYPE_STRING, &reason,
                                          DBUS_TYPE_UINT32, &flags, DBUS_TYPE_INVALID);
                 reply_message = dbus_connection_send_with_reply_and_block(connection, message, 200, &error);
 
