@@ -86,11 +86,12 @@ GtkWidget *shuffle;
 GtkMenuItem *menuitem_edit_switch_audio;
 GtkMenuItem *menuitem_edit_set_audiofile;
 GtkMenuItem *menuitem_edit_select_audio_lang;
-GtkMenu *menu_edit_audio_langs;
 GtkMenuItem *menuitem_edit_set_subtitle;
 GtkMenuItem *menuitem_edit_select_sub_lang;
-GtkMenu *menu_edit_sub_langs;
 GtkMenuItem *menuitem_lang;
+GtkWidget *tracks;
+GtkWidget *subtitles;
+
 
 GtkMenuItem *menuitem_edit_take_screenshot;
 GtkMenuItem *menuitem_edit_sep1;
@@ -155,7 +156,7 @@ GtkWidget *vbox;
 GtkWidget *hbox;
 GtkWidget *controls_box;
 
-GtkWidget *fixed;
+GtkWidget *media;
 GtkWidget *media_hbox;
 GtkWidget *media_label;
 GtkWidget *cover_art;
@@ -169,12 +170,12 @@ GtkWidget *details_video_codec;
 GtkWidget *details_video_fps;
 GtkWidget *details_video_bitrate;
 GtkWidget *details_video_chapters;
+GtkWidget *details_audio_format;
 GtkWidget *details_audio_codec;
 GtkWidget *details_audio_channels;
 GtkWidget *details_audio_bitrate;
 GtkWidget *details_audio_samplerate;
 
-GtkWidget *drawing_area;
 GdkPixbuf *pb_icon;
 GdkPixbuf *pb_button;
 
@@ -224,6 +225,8 @@ GtkTooltips *tooltip;
 GtkTooltips *volume_tip;
 #endif
 
+GtkWidget *config_window;
+
 GtkWidget *config_vo;
 GtkWidget *config_ao;
 GtkWidget *config_mixer;
@@ -271,6 +274,7 @@ GtkWidget *config_subtitle_color;
 GtkWidget *config_subtitle_outline;
 GtkWidget *config_subtitle_shadow;
 GtkWidget *config_subtitle_margin;
+GtkWidget *config_subtitle_fuzziness;
 GtkWidget *config_show_subtitles;
 
 GtkWidget *config_qt;
@@ -279,6 +283,7 @@ GtkWidget *config_wmp;
 GtkWidget *config_dvx;
 GtkWidget *config_midi;
 GtkWidget *config_noembed;
+GtkWidget *config_noscaling;
 
 GtkWidget *config_mplayer_bin;
 GtkWidget *config_mplayer_dvd_device;
@@ -311,7 +316,6 @@ glong last_movement_time;
 gboolean popup_handler(GtkWidget * widget, GdkEvent * event, void *data);
 gboolean delete_callback(GtkWidget * widget, GdkEvent * event, void *data);
 void config_close(GtkWidget * widget, void *data);
-gboolean allocate_fixed_callback(GtkWidget * widget, GtkAllocation * allocation, gpointer data);
 
 gboolean rew_callback(GtkWidget * widget, GdkEventExpose * event, void *data);
 gboolean play_callback(GtkWidget * widget, GdkEventExpose * event, void *data);
@@ -344,8 +348,7 @@ void create_folder_progress_window();
 void destroy_folder_progress_window();
 void update_status_icon();
 void setup_accelerators();
-void update_details_table();
-gboolean set_software_volume(int *data);
+gboolean set_software_volume(gdouble * data);
 gboolean set_adjust_layout(gpointer data);
 
 void show_fs_controls();
