@@ -32,6 +32,8 @@
 #include <pulse/glib-mainloop.h>
 #endif
 
+#include <math.h>
+
 GList *gm_audio_devices = NULL;
 gboolean gm_audio_debug = FALSE;
 void *gm_audio_server_volume_update_callback = NULL;
@@ -107,6 +109,37 @@ gboolean gm_audio_query_devices()
     device->volume = 1.0;
     gm_audio_devices = g_list_append(gm_audio_devices, device);
 
+    device = g_new0(AudioDevice, 1);
+    device->description = g_strdup("ALSA");
+    device->type = AUDIO_TYPE_SOFTVOL;
+    device->alsa_device_name = g_strdup("default");
+    device->mplayer_ao = g_strdup("alsa");
+    device->volume = 1.0;
+    gm_audio_devices = g_list_append(gm_audio_devices, device);
+
+    device = g_new0(AudioDevice, 1);
+    device->description = g_strdup("PulseAudio");
+    device->type = AUDIO_TYPE_SOFTVOL;
+    device->mplayer_ao = g_strdup("pulse");
+    device->volume = 1.0;
+    gm_audio_devices = g_list_append(gm_audio_devices, device);
+
+#ifdef __OpenBSD__
+    device = g_new0(AudioDevice, 1);
+    device->description = g_strdup("SNDIO");
+    device->type = AUDIO_TYPE_SOFTVOL;
+    device->mplayer_ao = g_strdup("sndio");
+    device->volume = 1.0;
+    gm_audio_devices = g_list_append(gm_audio_devices, device);
+
+    device = g_new0(AudioDevice, 1);
+    device->description = g_strdup("RTunes");
+    device->type = AUDIO_TYPE_SOFTVOL;
+    device->mplayer_ao = g_strdup("rtunes");
+    device->volume = 1.0;
+    gm_audio_devices = g_list_append(gm_audio_devices, device);
+#endif
+
 #ifdef HAVE_ASOUNDLIB
     snd_ctl_card_info_alloca(&info);
     snd_pcm_info_alloca(&pcminfo);
@@ -170,21 +203,12 @@ gboolean gm_audio_query_devices()
 
     }
 
-#else
-
-    device = g_new0(AudioDevice, 1);
-    device->description = g_strdup("ALSA");
-    device->type = AUDIO_TYPE_SOFTVOL;
-    device->alsa_device_name = g_strdup("default");
-    device->mplayer_ao = g_strdup("alsa");
-    device->volume = 1.0;
-    gm_audio_devices = g_list_append(gm_audio_devices, device);
-
 #endif
 
+
 #ifdef HAVE_PULSEAUDIO
 
-    pa_glib_mainloop *loop = pa_glib_mainloop_new(g_main_context_default());
+	pa_glib_mainloop *loop = pa_glib_mainloop_new(g_main_context_default());
     gm_audio_context = pa_context_new(pa_glib_mainloop_get_api(loop), "gm_audio_context");
     if (gm_audio_context) {
         pa_context_connect(gm_audio_context, NULL, 0, NULL);
@@ -194,15 +218,6 @@ gboolean gm_audio_query_devices()
     while (gtk_events_pending())
         gtk_main_iteration();
 
-#else
-
-    device = g_new0(AudioDevice, 1);
-    device->description = g_strdup("PulseAudio");
-    device->type = AUDIO_TYPE_SOFTVOL;
-    device->mplayer_ao = g_strdup("pulse");
-    device->volume = 1.0;
-    gm_audio_devices = g_list_append(gm_audio_devices, device);
-
 #endif
 
     return TRUE;
@@ -342,7 +357,7 @@ gboolean gm_audio_alsa_monitor(gpointer data)
     if (device->alsa_device_name && device->alsa_mixer)
         device->volume = get_alsa_volume(device->alsa_device_name, device->alsa_mixer);
 #endif
-	
+
     if (gm_audio_server_volume_update_callback && old_volume != device->volume)
         g_idle_add(gm_audio_server_volume_update_callback, NULL);
 
@@ -360,9 +375,6 @@ void gm_audio_set_server_volume_update_callback(AudioDevice * device, void *call
     }
 }
 
-
-
-
 #ifdef HAVE_PULSEAUDIO
 
 void gm_audio_pa_sink_update_volume_cb(pa_context * c, const pa_sink_info * i, int eol, gpointer data)
@@ -395,7 +407,7 @@ void gm_audio_pa_sink_update_volume_cb(pa_context * c, const pa_sink_info * i, i
         //printf("device volume = %f\n", device->volume);
     } else {
         // eol == -1 when the index requested is not found
-        if (eol == -1)
+        if (eol == -1 && device)
             device->volume = 0.0;
     }
 }
@@ -605,9 +617,9 @@ gboolean set_alsa_volume(gchar * device, gchar * mixer, gdouble volume)
             f_multi = ((float) (pmax - pmin));
             if (snd_mixer_selem_has_playback_switch(elem)) {
                 if (volume == 0) {
-                    snd_mixer_selem_set_playback_switch(elem, 0, 0);
+                    snd_mixer_selem_set_playback_switch_all(elem, 0);
                 } else {
-                    snd_mixer_selem_set_playback_switch(elem, 0, 1);
+                    snd_mixer_selem_set_playback_switch_all(elem, 1);
                 }
                 snd_mixer_selem_get_playback_switch(elem, 0, &playback);
             } else {
@@ -615,7 +627,7 @@ gboolean set_alsa_volume(gchar * device, gchar * mixer, gdouble volume)
             }
             if (playback == 1) {
                 set_vol = (gdouble) ((volume) * f_multi) + pmin;
-                snd_mixer_selem_set_playback_volume(elem, 0, set_vol);
+                snd_mixer_selem_set_playback_volume_all(elem, set_vol);
             }
             if (gm_audio_debug) {
                 printf("Setting Volume\n");
