@@ -43,9 +43,6 @@
 #include "common.h"
 #include "support.h"
 #include "dbus-interface.h"
-#include "thread.h"
-
-GMutex *thread_running = NULL;
 
 
 static GOptionEntry entries[] = {
@@ -65,7 +62,7 @@ static GOptionEntry entries[] = {
      N_("Last software volume percentage- only applied when remember_softvol is set to TRUE"),
      NULL},
     {"mixer", 0, 0, G_OPTION_ARG_STRING, &(audio_device.alsa_mixer), N_("Mixer to use"), NULL},
-    {"volume", 0, 0, G_OPTION_ARG_INT, &volume, N_("Set initial volume percentage"), NULL},
+    {"volume", 0, 0, G_OPTION_ARG_INT, &(pref_volume), N_("Set initial volume percentage"), NULL},
     {"showcontrols", 0, 0, G_OPTION_ARG_INT, &showcontrols, N_("Show the controls in window"),
      "[0|1]"},
     {"showsubtitles", 0, 0, G_OPTION_ARG_INT, &showsubtitles, N_("Show the subtitles if available"),
@@ -148,7 +145,35 @@ static GOptionEntry entries[] = {
     {NULL}
 };
 
-gboolean play(void *data);
+gboolean async_play_iter(void *data)
+{
+    next_iter = (GtkTreeIter *) (data);
+    // printf("state = %i\n", gmtk_media_player_get_state(GMTK_MEDIA_PLAYER(media)));
+    if (gmtk_media_player_get_state(GMTK_MEDIA_PLAYER(media)) == MEDIA_STATE_UNKNOWN) {
+        play_iter(next_iter, 0);
+        next_iter = NULL;
+    }
+
+    return FALSE;
+}
+
+gboolean play(void *data)
+{
+    PlayData *p = (PlayData *) data;
+
+    if (ok_to_play && p != NULL) {
+        if (!gtk_list_store_iter_is_valid(playliststore, &iter)) {
+            // printf("iter is not valid, getting first one\n");
+            gtk_tree_model_get_iter_first(GTK_TREE_MODEL(playliststore), &iter);
+        }
+        gtk_list_store_set(playliststore, &iter, PLAYLIST_COLUMN, p->playlist, ITEM_COLUMN, p->uri, -1);
+        play_iter(&iter, 0);
+    }
+    g_free(p);
+
+    return FALSE;
+}
+
 
 void play_next()
 {
@@ -198,21 +223,18 @@ void play_next()
 gint play_iter(GtkTreeIter * playiter, gint restart_second)
 {
 
-    ThreadData *thread_data = (ThreadData *) g_new0(ThreadData, 1);
-    GtkWidget *dialog;
-    gchar *error_msg = NULL;
     gchar *subtitle = NULL;
     gchar *audiofile = NULL;
     GtkTreePath *path;
-    gchar *local_file = NULL;
     gchar *uri = NULL;
-    gint count, pos;
+    gint count;
     gint playlist;
     gchar *title = NULL;
     gchar *artist = NULL;
     gchar *album = NULL;
     gchar *audio_codec;
     gchar *video_codec = NULL;
+    GtkAllocation alloc;
     gchar *demuxer = NULL;
     gboolean playable = TRUE;
     gint width;
@@ -231,9 +253,18 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
 #endif
 #endif
 
+    /*
+       if (!(gmtk_media_player_get_state(GMTK_MEDIA_PLAYER(media)) == MEDIA_STATE_UNKNOWN ||
+       gmtk_media_player_get_state(GMTK_MEDIA_PLAYER(media)) == MEDIA_STATE_QUIT)) {
+       while (gmtk_media_player_get_state(GMTK_MEDIA_PLAYER(media)) != MEDIA_STATE_UNKNOWN) {
+       gtk_main_iteration();
+       }
+       }
+     */
+
     if (gtk_list_store_iter_is_valid(playliststore, playiter)) {
         gtk_tree_model_get(GTK_TREE_MODEL(playliststore), playiter, ITEM_COLUMN, &uri,
-                           DESCRIPTION_COLUMN, &title,
+                           DESCRIPTION_COLUMN, &title, LENGTH_VALUE_COLUMN, &length_value,
                            ARTIST_COLUMN, &artist,
                            ALBUM_COLUMN, &album,
                            AUDIO_CODEC_COLUMN, &audio_codec,
@@ -252,7 +283,6 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
                 if (GTK_IS_WIDGET(list))
                     gtk_tree_view_scroll_to_cell(GTK_TREE_VIEW(list), path, NULL, FALSE, 0, 0);
                 buffer = gtk_tree_path_to_string(path);
-                pos = (gint) g_strtod(buffer, NULL);
                 g_free(buffer);
                 gtk_tree_path_free(path);
             }
@@ -261,8 +291,6 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
     } else {
         if (verbose > 1)
             printf("iter is invalid, nothing to play\n");
-        g_free(thread_data);
-        thread_data = NULL;
         return 0;
     }
 
@@ -271,62 +299,68 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
         printf("is playlist %i\n", playlist);
     }
 
-    mplayer_shutdown();
-
-    while (state != QUIT) {
-        gtk_main_iteration();
+    get_allocation(GTK_WIDGET(media), &alloc);
+    if (width == 0 || height == 0) {
+        alloc.width = 16;
+        alloc.height = 16;
+    } else {
+        alloc.width = width;
+        alloc.height = height;
     }
-
+    //printf("setting window size to %i x %i\n", alloc.width, alloc.height);
+    gtk_widget_size_allocate(GTK_WIDGET(media), &alloc);
     while (gtk_events_pending())
         gtk_main_iteration();
 
-    // wait for metadata to be available on this item
-    if (!streaming_media(uri) && !device_name(uri)) {
-        i = 0;
-        if (playable) {
-            while (demuxer == NULL && i < 50) {
-                g_free(title);
-                g_free(artist);
-                g_free(album);
-                g_free(audio_codec);
-                g_free(video_codec);
-                g_free(demuxer);
-                g_free(subtitle);
-                g_free(audiofile);
-                if (gtk_list_store_iter_is_valid(playliststore, playiter)) {
-                    gtk_tree_model_get(GTK_TREE_MODEL(playliststore), playiter, LENGTH_VALUE_COLUMN,
-                                       &length_value, DESCRIPTION_COLUMN, &title, ARTIST_COLUMN,
-                                       &artist, ALBUM_COLUMN, &album, AUDIO_CODEC_COLUMN,
-                                       &audio_codec, VIDEO_CODEC_COLUMN, &video_codec,
-                                       VIDEO_WIDTH_COLUMN, &width, VIDEO_HEIGHT_COLUMN, &height,
-                                       DEMUXER_COLUMN, &demuxer, COVERART_COLUMN, &pixbuf,
-                                       SUBTITLE_COLUMN, &subtitle, AUDIOFILE_COLUMN, &audiofile,
-                                       COUNT_COLUMN, &count, PLAYLIST_COLUMN, &playlist,
-                                       PLAYABLE_COLUMN, &playable, -1);
-                    if (!playable) {
-                        if (verbose)
-                            printf("%s is not marked as playable (%i)\n", uri, i);
-                        play_next();
-                        return 0;
-                    }
-                } else {
-                    if (verbose)
-                        printf("Current iter is not valid\n");
-                    return 1;   // error condition
-                }
-                gtk_main_iteration();
-                i++;
-                if (demuxer == NULL)
-                    g_usleep(10000);
-            }
-        } else {
-            if (verbose)
-                printf("%s is not marked as playable\n", uri);
-            play_next();
-            return 0;
-        }
+    /*
+       // wait for metadata to be available on this item
+       if (!streaming_media(uri) && !device_name(uri)) {
+       i = 0;
+       if (playable) {
+       while (demuxer == NULL && i < 50) {
+       g_free(title);
+       g_free(artist);
+       g_free(album);
+       g_free(audio_codec);
+       g_free(video_codec);
+       g_free(demuxer);
+       g_free(subtitle);
+       g_free(audiofile);
+       if (gtk_list_store_iter_is_valid(playliststore, playiter)) {
+       gtk_tree_model_get(GTK_TREE_MODEL(playliststore), playiter, LENGTH_VALUE_COLUMN,
+       &length_value, DESCRIPTION_COLUMN, &title, ARTIST_COLUMN,
+       &artist, ALBUM_COLUMN, &album, AUDIO_CODEC_COLUMN,
+       &audio_codec, VIDEO_CODEC_COLUMN, &video_codec,
+       VIDEO_WIDTH_COLUMN, &width, VIDEO_HEIGHT_COLUMN, &height,
+       DEMUXER_COLUMN, &demuxer, COVERART_COLUMN, &pixbuf,
+       SUBTITLE_COLUMN, &subtitle, AUDIOFILE_COLUMN, &audiofile,
+       COUNT_COLUMN, &count, PLAYLIST_COLUMN, &playlist,
+       PLAYABLE_COLUMN, &playable, -1);
+       if (!playable) {
+       if (verbose)
+       printf("%s is not marked as playable (%i)\n", uri, i);
+       play_next();
+       return 0;
+       }
+       } else {
+       if (verbose)
+       printf("Current iter is not valid\n");
+       return 1;   // error condition
+       }
+       gtk_main_iteration();
+       i++;
+       if (demuxer == NULL)
+       g_usleep(10000);
+       }
+       } else {
+       if (verbose)
+       printf("%s is not marked as playable\n", uri);
+       play_next();
+       return 0;
+       }
 
-    }
+       }
+     */
     // reset audio meter
     for (i = 0; i < METER_BARS; i++) {
         buckets[i] = 0;
@@ -411,50 +445,43 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
         gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem_view_info), FALSE);
     }
 
-    gtk_container_forall(GTK_CONTAINER(menu_edit_sub_langs), remove_langs, NULL);
+    if (subtitles)
+        gtk_container_forall(GTK_CONTAINER(subtitles), remove_langs, NULL);
     gtk_widget_set_sensitive(GTK_WIDGET(menuitem_edit_select_sub_lang), FALSE);
-    gtk_container_forall(GTK_CONTAINER(menu_edit_audio_langs), remove_langs, NULL);
+    if (tracks)
+        gtk_container_forall(GTK_CONTAINER(tracks), remove_langs, NULL);
     gtk_widget_set_sensitive(GTK_WIDGET(menuitem_edit_select_audio_lang), FALSE);
     lang_group = NULL;
     audio_group = NULL;
 
-    local_file = get_localfile_from_uri(uri);
-    if (local_file == NULL)
-        return 0;
-
-    g_strlcpy(thread_data->uri, uri, 2048);
-    g_strlcpy(thread_data->filename, local_file, 1024);
-    g_free(local_file);
-    thread_data->done = FALSE;
 
     if (subtitle != NULL) {
-        g_strlcpy(thread_data->subtitle, subtitle, 1024);
+        gmtk_media_player_set_attribute_string(GMTK_MEDIA_PLAYER(media), ATTRIBUTE_SUBTITLE_FILE, subtitle);
         g_free(subtitle);
+        subtitle = NULL;
     }
     if (audiofile != NULL) {
-        g_strlcpy(thread_data->audiofile, audiofile, 1024);
+        gmtk_media_player_set_attribute_string(GMTK_MEDIA_PLAYER(media), ATTRIBUTE_AUDIO_TRACK_FILE, audiofile);
         g_free(audiofile);
+        audiofile = NULL;
     }
-#if GTK2_12_ENABLED
-    volume = gtk_scale_button_get_value(GTK_SCALE_BUTTON(vol_slider));
-#else
-    volume = gtk_range_get_value(GTK_RANGE(vol_slider));
-#endif
 
-    if (g_ascii_strcasecmp(thread_data->filename, "") != 0) {
-        if (!device_name(thread_data->filename) && !streaming_media(thread_data->filename)) {
-            if (!g_file_test(thread_data->filename, G_FILE_TEST_EXISTS)) {
-                error_msg = g_strdup_printf("%s not found\n", thread_data->filename);
-                dialog =
-                    gtk_message_dialog_new(NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
-                                           GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "%s", error_msg);
-                gtk_window_set_title(GTK_WINDOW(dialog), "GNOME MPlayer Error");
-                gtk_dialog_run(GTK_DIALOG(dialog));
-                gtk_widget_destroy(dialog);
-                return 1;
-            }
-        }
-    }
+    /*
+       if (g_ascii_strcasecmp(thread_data->filename, "") != 0) {
+       if (!device_name(thread_data->filename) && !streaming_media(thread_data->filename)) {
+       if (!g_file_test(thread_data->filename, G_FILE_TEST_EXISTS)) {
+       error_msg = g_strdup_printf("%s not found\n", thread_data->filename);
+       dialog =
+       gtk_message_dialog_new(NULL, GTK_DIALOG_DESTROY_WITH_PARENT,
+       GTK_MESSAGE_ERROR, GTK_BUTTONS_CLOSE, "%s", error_msg);
+       gtk_window_set_title(GTK_WINDOW(dialog), "GNOME MPlayer Error");
+       gtk_dialog_run(GTK_DIALOG(dialog));
+       gtk_widget_destroy(dialog);
+       return 1;
+       }
+       }
+       }
+     */
 #ifdef GTK2_12_ENABLED
 #ifdef GIO_ENABLED
     // don't put it on the recent list, if it is running in plugin mode
@@ -501,104 +528,60 @@ gint play_iter(GtkTreeIter * playiter, gint restart_second)
     } else {
         g_strlcpy(idledata->demuxer, "", 64);
     }
-    if (audio_codec != NULL) {
-        g_strlcpy(idledata->audio_codec, audio_codec, 64);
-        g_free(audio_codec);
-    } else {
-        g_strlcpy(idledata->audio_codec, "", 64);
-    }
-    if (video_codec != NULL) {
-        g_strlcpy(idledata->video_codec, video_codec, 64);
-        g_free(video_codec);
-    } else {
-        g_strlcpy(idledata->video_codec, "", 64);
-    }
-
-    if (lastfile != NULL) {
-        g_free(lastfile);
-        lastfile = NULL;
-    }
-
-    lastfile = g_strdup(thread_data->filename);
 
     last_x = 0;
     last_y = 0;
     idledata->width = width;
     idledata->height = height;
-    idledata->original_h = -1;
-    idledata->original_w = -1;
-    if (width > 0 && height > 0) {
-        idledata->videopresent = 1;
-    } else {
-        idledata->videopresent = 0;
-    }
 
-    if (idledata->audio_codec != NULL && strlen(idledata->audio_codec) > 0) {
-        idledata->audiopresent = 1;
-    } else {
-        idledata->audiopresent = 0;
-    }
-
-    idledata->x = 0;
-    idledata->y = 0;
     idledata->cachepercent = -1.0;
     g_strlcpy(idledata->info, uri, 1024);
     set_media_info(idledata);
 
     streaming = 0;
-    subtitle_delay = 0.0;
 
     gm_store = gm_pref_store_new("gnome-mplayer");
     forcecache = gm_pref_store_get_boolean(gm_store, FORCECACHE);
     gm_pref_store_free(gm_store);
 
-    if (thread_data->filename != NULL && strlen(thread_data->filename) != 0) {
-        thread_data->player_window = 0;
-        thread_data->playlist = playlist;
-        thread_data->restart_second = restart_second;
-        thread_data->start_second = start_second;
-        thread_data->play_length = play_length;
-        thread_data->streaming = streaming_media(thread_data->uri);
-        idledata->streaming = thread_data->streaming;
-        streaming = thread_data->streaming;
-        g_strlcpy(idledata->video_format, "", 64);
-        g_strlcpy(idledata->video_fps, "", 16);
-        g_strlcpy(idledata->video_bitrate, "", 16);
-        g_strlcpy(idledata->audio_bitrate, "", 16);
-        g_strlcpy(idledata->audio_samplerate, "", 16);
-        g_strlcpy(idledata->audio_channels, "", 16);
-        idledata->has_chapters = FALSE;
-        idledata->windowid = get_player_window();
-        // these next 3 lines are here to make sure the window is available for mplayer to draw to
-        // for some vo's (like xv) if the window is not visible and big enough the vo setup fails
-        if (thread_data->streaming || thread_data->playlist) {
-            idledata->videopresent = 1;
-            gtk_widget_set_size_request(drawing_area, 16, 16);
-            gtk_widget_show_all(fixed);
-        } else {
-            g_idle_add(resize_window, idledata);
-        }
 
-        if (g_ascii_strcasecmp(uri, "dvdnav://") == 0) {
-            gtk_widget_show(menu_event_box);
-        } else {
-            gtk_widget_hide(menu_event_box);
-        }
-        while (gtk_events_pending())
-            gtk_main_iteration();
-
-        if (autostart) {
-            g_idle_add(hide_buttons, idledata);
-            js_state = STATE_PLAYING;
-            while (gtk_events_pending())
-                gtk_main_iteration();
-            thread = g_thread_create(launch_player, thread_data, TRUE, NULL);
-            if (thread == NULL)
-                printf("Unable to launch player thread\n");
-        }
-        autostart = 1;
+    if (g_ascii_strcasecmp(uri, "dvdnav://") == 0) {
+        gtk_widget_show(menu_event_box);
+    } else {
+        gtk_widget_hide(menu_event_box);
     }
 
+    if (autostart) {
+        g_idle_add(hide_buttons, idledata);
+        js_state = STATE_PLAYING;
+
+        if (g_str_has_prefix(uri, "mmshttp") || g_str_has_prefix(uri, "http") || g_str_has_prefix(uri, "mms")) {
+            gmtk_media_player_set_media_type(GMTK_MEDIA_PLAYER(media), TYPE_NETWORK);
+        } else if (g_str_has_prefix(uri, "dvd") || g_str_has_prefix(uri, "dvdnav")) {
+            gmtk_media_player_set_media_type(GMTK_MEDIA_PLAYER(media), TYPE_DVD);
+        } else if (g_str_has_prefix(uri, "cdda")) {
+            gmtk_media_player_set_media_type(GMTK_MEDIA_PLAYER(media), TYPE_CD);
+        } else if (g_str_has_prefix(uri, "vcd")) {
+            gmtk_media_player_set_media_type(GMTK_MEDIA_PLAYER(media), TYPE_VCD);
+        } else if (g_str_has_prefix(uri, "tv")) {
+            gmtk_media_player_set_media_type(GMTK_MEDIA_PLAYER(media), TYPE_TV);
+        } else if (g_str_has_prefix(uri, "dvb")) {
+            gmtk_media_player_set_media_type(GMTK_MEDIA_PLAYER(media), TYPE_DVB);
+        } else if (g_str_has_prefix(uri, "file")) {
+            gmtk_media_player_set_media_type(GMTK_MEDIA_PLAYER(media), TYPE_FILE);
+        } else {
+            // if all else fails it must be a network type
+            gmtk_media_player_set_media_type(GMTK_MEDIA_PLAYER(media), TYPE_NETWORK);
+        }
+
+        gmtk_media_player_set_attribute_boolean(GMTK_MEDIA_PLAYER(media), ATTRIBUTE_PLAYLIST, playlist);
+        gmtk_media_player_set_uri(GMTK_MEDIA_PLAYER(media), uri);
+        gmtk_media_player_set_state(GMTK_MEDIA_PLAYER(media), MEDIA_STATE_PLAY);
+
+    }
+    autostart = 1;
+
+
     return 0;
 }
 
@@ -620,6 +603,8 @@ int main(int argc, char *argv[])
     GError *error = NULL;
     GOptionContext *context;
     gint i;
+    gdouble volume = 100.0;
+
 #ifndef OS_WIN32
     struct sigaction sa;
 #endif
@@ -650,30 +635,14 @@ int main(int argc, char *argv[])
     dontplaynext = FALSE;
     idledata = (IdleData *) g_new0(IdleData, 1);
     idledata->videopresent = FALSE;
-    idledata->volume = 100.0;
-    idledata->mute = FALSE;
     idledata->length = 0.0;
-    idledata->brightness = 0;
-    idledata->contrast = 0;
-    idledata->gamma = 0;
-    idledata->hue = 0;
-    idledata->saturation = 0;
     idledata->device = NULL;
     idledata->cachepercent = -1.0;
-    g_strlcpy(idledata->video_format, "", 64);
-    g_strlcpy(idledata->video_codec, "", 64);
-    g_strlcpy(idledata->video_fps, "", 64);
-    g_strlcpy(idledata->video_bitrate, "", 64);
-    g_strlcpy(idledata->audio_codec, "", 64);
-    g_strlcpy(idledata->audio_bitrate, "", 64);
-    g_strlcpy(idledata->audio_samplerate, "", 64);
     selection = NULL;
-    lastfile = NULL;
     path = NULL;
     js_state = STATE_UNDEFINED;
     control_instance = TRUE;
     playlistname = NULL;
-    thread = NULL;
     rpconsole = NULL;
     subtitle = NULL;
     tv_device = NULL;
@@ -692,7 +661,6 @@ int main(int argc, char *argv[])
     stored_window_height = -1;
     cache_size = 0;
     forcecache = FALSE;
-    volume = -1;
     use_volume_option = FALSE;
     vertical_layout = FALSE;
     playlist_visible = FALSE;
@@ -707,6 +675,7 @@ int main(int argc, char *argv[])
     subtitle_color = NULL;
     subtitle_outline = FALSE;
     subtitle_shadow = FALSE;
+    subtitle_fuzziness = 0;
     disable_embeddedfonts = FALSE;
     quit_on_complete = FALSE;
     slide_away = NULL;
@@ -738,7 +707,6 @@ int main(int argc, char *argv[])
     disable_cover_art_fetch = FALSE;
     fullscreen = 0;
     vo = NULL;
-    dvdnav_title_is_menu = FALSE;
     data = NULL;
     max_data = NULL;
     details_table = NULL;
@@ -757,6 +725,9 @@ int main(int argc, char *argv[])
     gchar *filename;
     skip_fixed_allocation_on_show = FALSE;
     skip_fixed_allocation_on_hide = FALSE;
+    pref_volume = -1;
+    use_mplayer2 = FALSE;
+    enable_global_menu = FALSE;
 
 #ifndef OS_WIN32
     sa.sa_handler = hup_handler;
@@ -780,12 +751,9 @@ int main(int argc, char *argv[])
 #endif
 
     // call g_type_init or otherwise we can crash
-    g_type_init();
-
-    g_value_init(&ALLOW_SHRINK_TRUE, G_TYPE_BOOLEAN);
-    g_value_init(&ALLOW_SHRINK_FALSE, G_TYPE_BOOLEAN);
-    g_value_set_boolean(&ALLOW_SHRINK_FALSE, FALSE);
-    g_value_set_boolean(&ALLOW_SHRINK_TRUE, TRUE);
+    gtk_init(&argc, &argv);
+    if (!g_thread_supported())
+        g_thread_init(NULL);
 
     uri = g_strdup_printf("%s/gnome-mplayer/cover_art", g_get_user_config_dir());
     if (!g_file_test(uri, G_FILE_TEST_IS_DIR)) {
@@ -816,7 +784,7 @@ int main(int argc, char *argv[])
     fullscreen = gm_pref_store_get_boolean(gm_store, FULLSCREEN);
     softvol = gm_pref_store_get_boolean(gm_store, SOFTVOL);
     remember_softvol = gm_pref_store_get_boolean(gm_store, REMEMBER_SOFTVOL);
-    volume_softvol = gm_pref_store_get_int(gm_store, VOLUME_SOFTVOL);
+    volume_softvol = gm_pref_store_get_float(gm_store, VOLUME_SOFTVOL);
     volume_gain = gm_pref_store_get_int(gm_store, VOLUME_GAIN);
     forcecache = gm_pref_store_get_boolean(gm_store, FORCECACHE);
     vertical_layout = gm_pref_store_get_boolean(gm_store, VERTICAL);
@@ -849,6 +817,7 @@ int main(int argc, char *argv[])
     subtitle_outline = gm_pref_store_get_boolean(gm_store, SUBTITLEOUTLINE);
     subtitle_shadow = gm_pref_store_get_boolean(gm_store, SUBTITLESHADOW);
     subtitle_margin = gm_pref_store_get_int(gm_store, SUBTITLE_MARGIN);
+    subtitle_fuzziness = gm_pref_store_get_int(gm_store, SUBTITLE_FUZZINESS);
     showsubtitles = gm_pref_store_get_boolean_with_default(gm_store, SHOW_SUBTITLES, TRUE);
 
     qt_disabled = gm_pref_store_get_boolean(gmp_store, DISABLE_QT);
@@ -857,6 +826,7 @@ int main(int argc, char *argv[])
     dvx_disabled = gm_pref_store_get_boolean(gmp_store, DISABLE_DVX);
     midi_disabled = gm_pref_store_get_boolean(gmp_store, DISABLE_MIDI);
     embedding_disabled = gm_pref_store_get_boolean(gmp_store, DISABLE_EMBEDDING);
+    disable_embedded_scaling = gm_pref_store_get_boolean(gmp_store, DISABLE_EMBEDDED_SCALING);
     if (embed_window == 0) {
         single_instance = gm_pref_store_get_boolean(gm_store, SINGLE_INSTANCE);
         if (single_instance) {
@@ -864,6 +834,10 @@ int main(int argc, char *argv[])
             bring_to_front = gm_pref_store_get_boolean(gm_store, BRING_TO_FRONT);
         }
     }
+    enable_global_menu = gm_pref_store_get_boolean(gm_store, ENABLE_GLOBAL_MENU);
+    if (!enable_global_menu) {
+        enable_global_menu = (g_getenv("UBUNTU_MENUPROXY") == NULL ? FALSE : TRUE);
+    }
 
     mplayer_bin = gm_pref_store_get_string(gm_store, MPLAYER_BIN);
     if (mplayer_bin != NULL && !g_file_test(mplayer_bin, G_FILE_TEST_EXISTS)) {
@@ -960,10 +934,10 @@ int main(int argc, char *argv[])
             printf("Using MPlayer Software Volume control\n");
         if (remember_softvol && volume_softvol != -1) {
             if (verbose)
-                printf("Using last volume of %i%%\n", volume_softvol);
-            volume = (gdouble) volume_softvol;
+                printf("Using last volume of %f%%\n", volume_softvol * 100.0);
+            volume = (gdouble) volume_softvol *100.0;
         } else {
-            volume = 100;
+            volume = 100.0;
         }
     }
 
@@ -979,10 +953,6 @@ int main(int argc, char *argv[])
         printf(_("Run 'gnome-mplayer --help' to see a full list of available command line options.\n"));
         return 1;
     }
-
-    if (!g_thread_supported())
-        g_thread_init(NULL);
-
     // if (verbose)
     //      printf("Threading support enabled = %i\n",g_thread_supported());
 
@@ -1000,12 +970,6 @@ int main(int argc, char *argv[])
     create_window(embed_window);
 
     autopause = FALSE;
-    state = QUIT;
-    channel_in = NULL;
-    channel_out = NULL;
-    channel_err = NULL;
-
-    thread_running = g_mutex_new();
     slide_away = g_mutex_new();
     mplayer_complete_cond = g_cond_new();
 #ifdef GIO_ENABLED
@@ -1046,24 +1010,26 @@ int main(int argc, char *argv[])
             do {
                 mnt = getmntent(fp);
                 if (mnt)
-                    //printf("%s is at %s\n",mnt->mnt_fsname,mnt->mnt_dir);
-                    if (argv[fileindex] != NULL && mnt->mnt_fsname != NULL) {
-                        if (strcmp(argv[fileindex], mnt->mnt_fsname) == 0)
-                            break;
-                    }
+                    printf("%s is at %s\n", mnt->mnt_fsname, mnt->mnt_dir);
+                if (argv[fileindex] != NULL && mnt && mnt->mnt_fsname != NULL) {
+                    if (strcmp(argv[fileindex], mnt->mnt_fsname) == 0)
+                        break;
+                }
             }
             while (mnt);
             endmntent(fp);
 #endif
-            if (mnt) {
+            if (mnt && mnt->mnt_dir) {
                 printf("%s is mounted on %s\n", argv[fileindex], mnt->mnt_dir);
                 uri = g_strdup_printf("%s/VIDEO_TS", mnt->mnt_dir);
                 stat(uri, &buf);
                 g_free(uri);
                 if (S_ISDIR(buf.st_mode)) {
-                    add_item_to_playlist("dvd://", 0);
+                    add_item_to_playlist("dvdnav://", 0);
                     gtk_tree_model_get_iter_first(GTK_TREE_MODEL(playliststore), &iter);
-                    play_iter(&iter, 0);
+                    gmtk_media_player_set_media_type(GMTK_MEDIA_PLAYER(media), TYPE_DVD);
+                    //play_iter(&iter, 0);
+                    playiter = TRUE;
                 } else {
                     uri = g_strdup_printf("file://%s", mnt->mnt_dir);
                     create_folder_progress_window();
@@ -1092,29 +1058,39 @@ int main(int argc, char *argv[])
                 }
             }
         } else if (S_ISDIR(buf.st_mode)) {
-            create_folder_progress_window();
-            uri = NULL;
-#ifdef GIO_ENABLED
-            file = g_file_new_for_commandline_arg(argv[fileindex]);
-            if (file != NULL) {
-                uri = g_file_get_uri(file);
-                g_object_unref(file);
-            }
-#else
-            uri = g_filename_to_uri(argv[fileindex], NULL, NULL);
-#endif
-            add_folder_to_playlist_callback(uri, NULL);
+            uri = g_strdup_printf("%s/VIDEO_TS", argv[fileindex]);
+            stat(uri, &buf);
             g_free(uri);
-            destroy_folder_progress_window();
-            if (random_order) {
+            if (S_ISDIR(buf.st_mode)) {
+                add_item_to_playlist("dvdnav://", 0);
                 gtk_tree_model_get_iter_first(GTK_TREE_MODEL(playliststore), &iter);
-                randomize_playlist(playliststore);
-            }
-            if (gtk_tree_model_get_iter_first(GTK_TREE_MODEL(playliststore), &iter)) {
+                gmtk_media_player_set_media_type(GMTK_MEDIA_PLAYER(media), TYPE_DVD);
                 //play_iter(&iter, 0);
                 playiter = TRUE;
+            } else {
+                create_folder_progress_window();
+                uri = NULL;
+#ifdef GIO_ENABLED
+                file = g_file_new_for_commandline_arg(argv[fileindex]);
+                if (file != NULL) {
+                    uri = g_file_get_uri(file);
+                    g_object_unref(file);
+                }
+#else
+                uri = g_filename_to_uri(argv[fileindex], NULL, NULL);
+#endif
+                add_folder_to_playlist_callback(uri, NULL);
+                g_free(uri);
+                destroy_folder_progress_window();
+                if (random_order) {
+                    gtk_tree_model_get_iter_first(GTK_TREE_MODEL(playliststore), &iter);
+                    randomize_playlist(playliststore);
+                }
+                if (gtk_tree_model_get_iter_first(GTK_TREE_MODEL(playliststore), &iter)) {
+                    //play_iter(&iter, 0);
+                    playiter = TRUE;
+                }
             }
-
         } else {
             // local file
             // detect if playlist here, so even if not specified it can be picked up
@@ -1180,16 +1156,22 @@ int main(int argc, char *argv[])
     gm_audio_update_device(&audio_device);
     gm_audio_get_volume(&audio_device);
     gm_audio_set_server_volume_update_callback(&audio_device, set_volume);
+    set_media_player_attributes(media);
+
     if (!softvol) {
-        printf("The volume on '%s' is %f\n", audio_device.description, audio_device.volume);
+        if (pref_volume != -1) {
+            audio_device.volume = (gdouble) pref_volume / 100.0;
+        }
+        if (verbose)
+            printf("The volume on '%s' is %f\n", audio_device.description, audio_device.volume);
         volume = audio_device.volume * 100;
     } else {
         audio_device.volume = volume / 100.0;
     }
 #ifdef GTK2_12_ENABLED
-    gtk_scale_button_set_value(GTK_SCALE_BUTTON(vol_slider), audio_device.volume * 100.0);
+    gtk_scale_button_set_value(GTK_SCALE_BUTTON(vol_slider), audio_device.volume);
 #else
-    gtk_range_set_value(GTK_RANGE(vol_slider), audio_device.volume * 100.0);
+    gtk_range_set_value(GTK_RANGE(vol_slider), audio_device.volume);
 #endif
     use_volume_option = detect_volume_option();
 
