@@ -61,7 +61,7 @@ gboolean playlist_popup_handler(GtkWidget * widget, GdkEvent * event, void *data
 
 
     menu = GTK_MENU(widget);
-    gtk_widget_grab_focus(fixed);
+    gtk_widget_grab_focus(media);
     if (event->type == GDK_BUTTON_PRESS) {
 
         event_button = (GdkEventButton *) event;
@@ -237,7 +237,7 @@ gboolean playlist_drop_callback(GtkWidget * widget, GdkDragContext * dc,
 
         if (gtk_tree_model_iter_n_children(GTK_TREE_MODEL(playliststore), NULL) == 1) {
             gtk_tree_model_get_iter_first(GTK_TREE_MODEL(playliststore), &iter);
-            play_iter(&iter, 0);
+            g_idle_add(async_play_iter, &iter);
 
         } else {
             gtk_widget_set_sensitive(GTK_WIDGET(menuitem_edit_random), TRUE);
@@ -301,6 +301,7 @@ gboolean playlist_enter_callback(GtkWidget * widget, GdkEventMotion * event, gpo
 gboolean playlist_leave_callback(GtkWidget * widget, GdkEventMotion * event, gpointer user_data)
 {
     gtk_tree_view_set_enable_search(GTK_TREE_VIEW(list), FALSE);
+    gtk_widget_grab_focus(play_event_box);
     setup_accelerators(TRUE);
     return TRUE;
 }
@@ -650,8 +651,7 @@ void add_folder_to_playlist(GtkWidget * widget, void *data)
 
     if (count == 0 && filecount > 0) {
         gtk_tree_model_get_iter_first(GTK_TREE_MODEL(playliststore), &iter);
-        play_iter(&iter, 0);
-        dontplaynext = FALSE;
+        g_idle_add(async_play_iter, &iter);
     }
 }
 
@@ -689,7 +689,7 @@ void clear_playlist(GtkWidget * widget, void *data)
 {
 
     dontplaynext = TRUE;
-    mplayer_shutdown();
+    //mplayer_shutdown();
     gtk_list_store_clear(playliststore);
     gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(menuitem_edit_random), FALSE);
     gtk_widget_set_sensitive(GTK_WIDGET(menuitem_edit_random), FALSE);
@@ -776,9 +776,8 @@ gboolean playlist_select_callback(GtkTreeView * view, GtkTreePath * path, GtkTre
 
     if (gtk_tree_model_get_iter(GTK_TREE_MODEL(playliststore), &iter, path)) {
         dontplaynext = TRUE;
-        mplayer_shutdown();
-        play_iter(&iter, 0);
-        dontplaynext = FALSE;
+        gmtk_media_player_set_state(GMTK_MEDIA_PLAYER(media), MEDIA_STATE_QUIT);
+        g_idle_add(async_play_iter, &iter);
     }
     return FALSE;
 }
@@ -801,8 +800,17 @@ void shuffle_callback(GtkWidget * widget, void *data)
 
 void menuitem_view_playlist_callback(GtkMenuItem * menuitem, void *data)
 {
+    static gboolean old_resize_on_new_media;
+
     playlist_visible = gtk_check_menu_item_get_active(GTK_CHECK_MENU_ITEM(menuitem));
     gtk_tree_view_set_enable_search(GTK_TREE_VIEW(list), playlist_visible);
+    if (playlist_visible) {
+        old_resize_on_new_media = resize_on_new_media;
+        resize_on_new_media = FALSE;
+    } else {
+        resize_on_new_media = old_resize_on_new_media;
+    }
+
     if (remember_loc)
         use_remember_loc = TRUE;
     adjust_layout();
@@ -818,7 +826,6 @@ void create_playlist_widget()
     GtkWidget *scrolled;
     GtkCellRenderer *renderer;
     GtkTreeViewColumn *column;
-    GtkWidget *box;
     GtkWidget *ctrlbox;
     GtkWidget *closebox;
     GtkWidget *hbox;
@@ -848,7 +855,6 @@ void create_playlist_widget()
     plvbox = gtk_vbox_new(FALSE, 12);
     hbox = gtk_hbox_new(FALSE, 12);
     gtk_box_set_homogeneous(GTK_BOX(hbox), FALSE);
-    box = gtk_hbox_new(FALSE, 10);
     ctrlbox = gtk_hbox_new(FALSE, 0);
     closebox = gtk_hbox_new(FALSE, 0);
 
@@ -857,6 +863,7 @@ void create_playlist_widget()
     gtk_tree_view_set_reorderable(GTK_TREE_VIEW(list), FALSE);
     gtk_widget_add_events(list, GDK_BUTTON_PRESS_MASK);
     gtk_widget_set_size_request(GTK_WIDGET(list), -1, -1);
+    gtk_tree_view_set_column_drag_function(GTK_TREE_VIEW(list), NULL, NULL, NULL);
 
     selection = gtk_tree_view_get_selection(GTK_TREE_VIEW(list));
     if (gtk_list_store_iter_is_valid(playliststore, &iter)) {
@@ -887,7 +894,7 @@ void create_playlist_widget()
                       GTK_DEST_DEFAULT_DROP, target_entry, i, GDK_ACTION_LINK);
 
     //Connect the signal for DnD
-    g_signal_connect(GTK_OBJECT(plvbox), "drag_data_received", G_CALLBACK(playlist_drop_callback), NULL);
+    g_signal_connect(G_OBJECT(plvbox), "drag_data_received", G_CALLBACK(playlist_drop_callback), NULL);
 
 #ifdef GTK2_12_ENABLED
 #else
@@ -910,8 +917,10 @@ void create_playlist_widget()
         g_strfreev(split);
     }
     gtk_tree_view_column_set_expand(column, TRUE);
+
     //gtk_tree_view_column_set_max_width(column, 40);
     g_object_set(renderer, "width-chars", 40, NULL);
+    gtk_tree_view_column_set_reorderable(column, TRUE);
     gtk_tree_view_column_set_resizable(column, TRUE);
     gtk_tree_view_column_set_sort_column_id(column, DESCRIPTION_COLUMN);
     gtk_tree_view_append_column(GTK_TREE_VIEW(list), column);
@@ -922,6 +931,7 @@ void create_playlist_widget()
     //gtk_tree_view_column_set_max_width(column, 20);
     g_object_set(renderer, "width-chars", 20, NULL);
     gtk_tree_view_column_set_alignment(column, 0.0);
+    gtk_tree_view_column_set_reorderable(column, TRUE);
     gtk_tree_view_column_set_resizable(column, TRUE);
     gtk_tree_view_column_set_sort_column_id(column, ARTIST_COLUMN);
     gtk_tree_view_append_column(GTK_TREE_VIEW(list), column);
@@ -932,6 +942,7 @@ void create_playlist_widget()
     //gtk_tree_view_column_set_max_width(column, 20);
     g_object_set(renderer, "width-chars", 20, NULL);
     gtk_tree_view_column_set_alignment(column, 0.0);
+    gtk_tree_view_column_set_reorderable(column, TRUE);
     gtk_tree_view_column_set_resizable(column, TRUE);
     gtk_tree_view_column_set_sort_column_id(column, ALBUM_COLUMN);
     gtk_tree_view_append_column(GTK_TREE_VIEW(list), column);
@@ -942,7 +953,9 @@ void create_playlist_widget()
     //gtk_tree_view_column_set_expand(column, FALSE);
     gtk_tree_view_column_set_alignment(column, 1.0);
     g_object_set(renderer, "xalign", 1.0, NULL);
+    gtk_tree_view_column_set_reorderable(column, TRUE);
     gtk_tree_view_column_set_resizable(column, FALSE);
+    gtk_tree_view_column_set_sort_column_id(column, LENGTH_COLUMN);
     gtk_tree_view_append_column(GTK_TREE_VIEW(list), column);
 
 
@@ -950,6 +963,7 @@ void create_playlist_widget()
     column = gtk_tree_view_column_new_with_attributes(_("Count"), renderer, "text", COUNT_COLUMN, NULL);
     //gtk_tree_view_column_set_expand(column, FALSE);
     g_object_set(renderer, "xalign", 1.0, NULL);
+    gtk_tree_view_column_set_reorderable(column, TRUE);
     gtk_tree_view_column_set_resizable(column, FALSE);
     gtk_tree_view_column_set_sort_column_id(column, COUNT_COLUMN);
     gtk_tree_view_append_column(GTK_TREE_VIEW(list), column);
@@ -958,6 +972,7 @@ void create_playlist_widget()
     column = gtk_tree_view_column_new_with_attributes(_("Order"), renderer, "text", PLAY_ORDER_COLUMN, NULL);
     //gtk_tree_view_column_set_expand(column, FALSE);
     g_object_set(renderer, "xalign", 1.0, NULL);
+    gtk_tree_view_column_set_reorderable(column, TRUE);
     gtk_tree_view_column_set_resizable(column, FALSE);
     gtk_tree_view_column_set_sort_column_id(column, PLAY_ORDER_COLUMN);
     gtk_tree_view_append_column(GTK_TREE_VIEW(list), column);
@@ -972,7 +987,7 @@ void create_playlist_widget()
 #endif
     gtk_container_add(GTK_CONTAINER(plclose), gtk_image_new_from_stock(GTK_STOCK_CLOSE, GTK_ICON_SIZE_MENU));
 
-    g_signal_connect_swapped(GTK_OBJECT(plclose), "clicked", G_CALLBACK(playlist_close), NULL);
+    g_signal_connect_swapped(G_OBJECT(plclose), "clicked", G_CALLBACK(playlist_close), NULL);
 
 
     loadlist = gtk_button_new();
@@ -986,7 +1001,7 @@ void create_playlist_widget()
 #endif
     gtk_container_add(GTK_CONTAINER(loadlist), gtk_image_new_from_stock(GTK_STOCK_OPEN, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), loadlist, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(loadlist), "clicked", G_CALLBACK(load_playlist), NULL);
+    g_signal_connect(G_OBJECT(loadlist), "clicked", G_CALLBACK(load_playlist), NULL);
 
     savelist = gtk_button_new();
 #ifdef GTK2_12_ENABLED
@@ -997,7 +1012,7 @@ void create_playlist_widget()
 #endif
     gtk_container_add(GTK_CONTAINER(savelist), gtk_image_new_from_stock(GTK_STOCK_SAVE, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), savelist, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(savelist), "clicked", G_CALLBACK(save_playlist), NULL);
+    g_signal_connect(G_OBJECT(savelist), "clicked", G_CALLBACK(save_playlist), NULL);
 
     add = gtk_button_new();
 #ifdef GTK2_12_ENABLED
@@ -1008,7 +1023,7 @@ void create_playlist_widget()
 #endif
     gtk_button_set_image(GTK_BUTTON(add), gtk_image_new_from_stock(GTK_STOCK_ADD, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), add, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(add), "clicked", G_CALLBACK(add_to_playlist), NULL);
+    g_signal_connect(G_OBJECT(add), "clicked", G_CALLBACK(add_to_playlist), NULL);
 
     remove = gtk_button_new();
 #ifdef GTK2_12_ENABLED
@@ -1019,7 +1034,7 @@ void create_playlist_widget()
 #endif
     gtk_button_set_image(GTK_BUTTON(remove), gtk_image_new_from_stock(GTK_STOCK_REMOVE, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), remove, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(remove), "clicked", G_CALLBACK(remove_from_playlist), list);
+    g_signal_connect(G_OBJECT(remove), "clicked", G_CALLBACK(remove_from_playlist), list);
 
     add_folder = gtk_button_new();
 #ifdef GTK2_12_ENABLED
@@ -1030,7 +1045,7 @@ void create_playlist_widget()
 #endif
     gtk_button_set_image(GTK_BUTTON(add_folder), gtk_image_new_from_stock(GTK_STOCK_DIRECTORY, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), add_folder, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(add_folder), "clicked", G_CALLBACK(add_folder_to_playlist), list);
+    g_signal_connect(G_OBJECT(add_folder), "clicked", G_CALLBACK(add_folder_to_playlist), list);
 
     clear = gtk_button_new();
 #ifdef GTK2_12_ENABLED
@@ -1041,7 +1056,7 @@ void create_playlist_widget()
 #endif
     gtk_button_set_image(GTK_BUTTON(clear), gtk_image_new_from_stock(GTK_STOCK_CLEAR, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), clear, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(clear), "clicked", G_CALLBACK(clear_playlist), list);
+    g_signal_connect(G_OBJECT(clear), "clicked", G_CALLBACK(clear_playlist), list);
 
     up = gtk_button_new();
 #ifdef GTK2_12_ENABLED
@@ -1052,7 +1067,7 @@ void create_playlist_widget()
 #endif
     gtk_button_set_image(GTK_BUTTON(up), gtk_image_new_from_stock(GTK_STOCK_GO_UP, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), up, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(up), "clicked", G_CALLBACK(move_item_up), list);
+    g_signal_connect(G_OBJECT(up), "clicked", G_CALLBACK(move_item_up), list);
     gtk_widget_set_sensitive(up, FALSE);
 
     down = gtk_button_new();
@@ -1064,7 +1079,7 @@ void create_playlist_widget()
 #endif
     gtk_button_set_image(GTK_BUTTON(down), gtk_image_new_from_stock(GTK_STOCK_GO_DOWN, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), down, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(down), "clicked", G_CALLBACK(move_item_down), list);
+    g_signal_connect(G_OBJECT(down), "clicked", G_CALLBACK(move_item_down), list);
     gtk_widget_set_sensitive(down, FALSE);
 
 
@@ -1077,7 +1092,7 @@ void create_playlist_widget()
 #endif
     gtk_button_set_image(GTK_BUTTON(undo), gtk_image_new_from_stock(GTK_STOCK_UNDO, GTK_ICON_SIZE_MENU));
     gtk_box_pack_start(GTK_BOX(ctrlbox), undo, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(undo), "clicked", G_CALLBACK(undo_playlist_sort), list);
+    g_signal_connect(G_OBJECT(undo), "clicked", G_CALLBACK(undo_playlist_sort), list);
     gtk_widget_set_sensitive(undo, TRUE);
 
 
@@ -1098,7 +1113,7 @@ void create_playlist_widget()
                              gtk_image_new_from_icon_name("media-playlist-repeat", GTK_ICON_SIZE_MENU));
     }
     gtk_box_pack_start(GTK_BOX(ctrlbox), repeat, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(repeat), "clicked", G_CALLBACK(repeat_callback), NULL);
+    g_signal_connect(G_OBJECT(repeat), "clicked", G_CALLBACK(repeat_callback), NULL);
     gtk_widget_set_sensitive(repeat, TRUE);
 
     shuffle = gtk_button_new();
@@ -1113,7 +1128,7 @@ void create_playlist_widget()
                              gtk_image_new_from_icon_name("media-playlist-shuffle", GTK_ICON_SIZE_MENU));
     }
     gtk_box_pack_start(GTK_BOX(ctrlbox), shuffle, FALSE, FALSE, 0);
-    g_signal_connect(GTK_OBJECT(shuffle), "clicked", G_CALLBACK(shuffle_callback), NULL);
+    g_signal_connect(G_OBJECT(shuffle), "clicked", G_CALLBACK(shuffle_callback), NULL);
     gtk_widget_set_sensitive(shuffle, TRUE);
 
 
@@ -1141,13 +1156,13 @@ void create_playlist_widget()
 
     playlist_popup_menu = GTK_MENU(gtk_menu_new());
     playlist_set_subtitle = GTK_MENU_ITEM(gtk_image_menu_item_new_with_mnemonic(_("_Set Subtitle")));
-    g_signal_connect(GTK_OBJECT(playlist_set_subtitle), "activate", G_CALLBACK(playlist_set_subtitle_callback), list);
+    g_signal_connect(G_OBJECT(playlist_set_subtitle), "activate", G_CALLBACK(playlist_set_subtitle_callback), list);
 
-    gtk_menu_append(playlist_popup_menu, GTK_WIDGET(playlist_set_subtitle));
+    gtk_menu_shell_append(GTK_MENU_SHELL(playlist_popup_menu), GTK_WIDGET(playlist_set_subtitle));
     playlist_set_audiofile = GTK_MENU_ITEM(gtk_image_menu_item_new_with_mnemonic(_("Set Audi_o")));
-    g_signal_connect(GTK_OBJECT(playlist_set_audiofile), "activate", G_CALLBACK(playlist_set_audiofile_callback), list);
+    g_signal_connect(G_OBJECT(playlist_set_audiofile), "activate", G_CALLBACK(playlist_set_audiofile_callback), list);
 
-    gtk_menu_append(playlist_popup_menu, GTK_WIDGET(playlist_set_audiofile));
+    gtk_menu_shell_append(GTK_MENU_SHELL(playlist_popup_menu), GTK_WIDGET(playlist_set_audiofile));
     g_signal_connect_swapped(G_OBJECT(list),
                              "button_press_event", G_CALLBACK(playlist_popup_handler), G_OBJECT(playlist_popup_menu));
     gtk_widget_show_all(GTK_WIDGET(playlist_popup_menu));
