@@ -1153,9 +1153,6 @@ gboolean device_name(gchar * filename)
 
 gchar *metadata_to_utf8(gchar * string)
 {
-    const gchar *lang;
-    lang = g_getenv("LANG");
-
     if (metadata_codepage != NULL && strlen(metadata_codepage) > 1) {
         // zh_TW usually use BIG5 on tags, if the file is from Windows
         if (g_utf8_validate(string, strlen(string), NULL) == FALSE) {
@@ -1500,9 +1497,21 @@ MetaData *get_metadata(gchar * uri)
     while (output != NULL && output[ac] != NULL) {
         if (verbose > 1)
             printf("METADATA:%s\n", output[ac]);
+
         if (strstr(output[ac], "MOV: missing header (moov/cmov) chunk") != NULL) {
             missing_header = TRUE;
         }
+
+        if (strstr(output[ac], "Title: ") != 0) {
+            localtitle = strstr(output[ac], "Title: ") + strlen("Title: ");
+            localtitle = g_strchomp(localtitle);
+            if (title != NULL) {
+                g_free(title);
+                title = NULL;
+            }
+            title = g_strdup(localtitle);
+        }
+
         ac++;
     }
 
@@ -1754,10 +1763,16 @@ gboolean add_item_to_playlist(const gchar * uri, gint playlist)
         data = (MetaData *) g_new0(MetaData, 1);
         data->title = g_strdup_printf("CD Track %s", uri + strlen("cdda://"));
     } else if (device_name(local_uri)) {
-        if (g_ascii_strncasecmp(uri, "dvdnav://", strlen("dvdnav://") == 0)) {
+        if (g_ascii_strncasecmp(uri, "dvdnav://", strlen("dvdnav://")) == 0) {
             loop = 1;
         }
         retrieve = TRUE;
+        if (g_ascii_strncasecmp(uri, "dvb://", strlen("dvb://")) == 0) {
+            retrieve = FALSE;
+        }
+        if (g_ascii_strncasecmp(uri, "tv://", strlen("tv://")) == 0) {
+            retrieve = FALSE;
+        }
         data = get_basic_metadata(local_uri);
 
     } else {
@@ -1775,7 +1790,7 @@ gboolean add_item_to_playlist(const gchar * uri, gint playlist)
 #endif
         data = (MetaData *) g_new0(MetaData, 1);
         slash = g_strrstr(unescaped, "/");
-        if (slash != NULL) {
+        if (slash != NULL && strlen(slash + sizeof(gchar)) > 0) {
             data->title = g_strdup_printf("[Stream] %s", slash + sizeof(gchar));
         } else {
             data->title = g_strdup_printf("[Stream] %s", unescaped);
@@ -2652,7 +2667,7 @@ gpointer get_cover_art(gpointer data)
                     url = get_cover_art_url(NULL, NULL, metadata->album);
             }
             if (url == NULL) {
-                if ((p = strstr(metadata->title, " - ")) != NULL) {
+                if (metadata->title != NULL && (p = strstr(metadata->title, " - ")) != NULL) {
                     p[0] = '\0';
                     g_free(path);
                     path = g_strdup_printf("%s/gnome-mplayer/cover_art/Unknown", g_get_user_cache_dir());
@@ -2774,7 +2789,7 @@ gboolean detect_volume_option()
         av[ac++] = g_strdup_printf("%s", mplayer_bin);
     }
     av[ac++] = g_strdup_printf("-volume");
-    av[ac++] = g_strdup_printf("%i", (gint) idledata->volume);
+    av[ac++] = g_strdup_printf("%i", (gint) (audio_device.volume * 100.0));
     av[ac++] = g_strdup_printf("-noidle");
     av[ac++] = g_strdup_printf("-softvol");
     av[ac] = NULL;
@@ -2803,6 +2818,9 @@ gboolean detect_volume_option()
         if (g_ascii_strncasecmp(output[ac], "Unknown option", strlen("Unknown option")) == 0) {
             ret = FALSE;
         }
+        if (g_ascii_strncasecmp(output[ac], "MPlayer2", strlen("MPlayer2")) == 0) {
+            use_mplayer2 = TRUE;
+        }
         ac++;
     }
     g_strfreev(output);
@@ -2834,7 +2852,9 @@ gboolean map_af_export_file(gpointer data)
         return TRUE;
 
     if (data != NULL) {
-        idle->mapped_af_export = g_mapped_file_new((gchar *) idle->af_export, FALSE, NULL);
+        idle->mapped_af_export =
+            g_mapped_file_new(gmtk_media_player_get_attribute_string
+                              (GMTK_MEDIA_PLAYER(media), ATTRIBUTE_AF_EXPORT_FILENAME), FALSE, NULL);
     }
     return FALSE;
 }
@@ -2849,7 +2869,6 @@ gboolean unmap_af_export_file(gpointer data)
     if (idle->mapped_af_export) {
         g_mapped_file_free(idle->mapped_af_export);
         idle->mapped_af_export = NULL;
-        g_unlink((gchar *) idle->af_export);
     }
 
     gmtk_audio_meter_set_data(GMTK_AUDIO_METER(audio_meter), NULL);
